@@ -94,7 +94,9 @@ class PageNotFoundRedirectMiddleware:
 
         redirects = cache.get(DJANGO_REGEX_REDIRECTS_CACHE_KEY)
         if redirects is None:
-            redirects = list(PageNotFoundEntry.objects.all().values())
+            redirects = list(
+                PageNotFoundEntry.objects.all().order_by("fallback_redirect").values()
+            )
             cache.set(
                 DJANGO_REGEX_REDIRECTS_CACHE_KEY,
                 redirects,
@@ -108,12 +110,12 @@ class PageNotFoundRedirectMiddleware:
                 self.updateHitCount(redirect["id"])
 
                 target_redirect_url = self.get_redirect_to_page_or_url(redirect)
-                if not target_redirect_url:
-                    # print("No target redirect url found")
-                    return response  # no redirect found, return 404
-
-                return self.HttpRedirect301302(
-                    request, target_redirect_url, redirect["permanent"]
+                return (
+                    self.HttpRedirect301302(
+                        request, target_redirect_url, redirect["permanent"]
+                    )
+                    if target_redirect_url
+                    else response
                 )
 
             if settings.APPEND_SLASH and not request.path.endswith("/"):
@@ -133,7 +135,9 @@ class PageNotFoundRedirectMiddleware:
         )
         if regular_expressions_redirects is None:
             regular_expressions_redirects = list(
-                PageNotFoundEntry.objects.filter(regular_expression=True).values()
+                PageNotFoundEntry.objects.filter(regular_expression=True)
+                .order_by("fallback_redirect")
+                .values()
             )
             cache.set(
                 DJANGO_REGEX_REDIRECTS_CACHE_REGEX_KEY,
@@ -145,7 +149,9 @@ class PageNotFoundRedirectMiddleware:
             # print(f"Checking {redirect['url']} with {full_path}")
             try:
                 old_path = re.compile(redirect["url"], re.IGNORECASE)
+                # print(f"Old path: {old_path}")
             except re.error:
+                # print(f"Regexp compilation error: {redirect['url']}")
                 continue
 
             if old_path.match(full_path):
